==> mysocials-ui_1.0.4-1.tar.gz: mysocials-ui-1.0.4/translations/mysocials_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.ui" line="17"/>
        <source>MySocials</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.ui" line="57"/>
        <source>toolBar</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="117"/>
        <source>&amp;Friends</source>
        <translation>&amp;Друзья</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="124"/>
        <source>&amp;Messages</source>
        <translation>&amp;Сообщения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="131"/>
        <source>&amp;Albums</source>
        <translation>&amp;Альбомы</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="138"/>
        <source>&amp;News</source>
        <translation>&amp;Новости</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="144"/>
        <source>&amp;More</source>
        <translation>&amp;Другое</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="157"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="158"/>
        <source>Full screen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="163"/>
        <source>&amp;Upload images</source>
        <translation>&amp;Загрузить фотографии</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="168"/>
        <source>&amp;Exit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="175"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="178"/>
        <source>Accounts</source>
        <translation>Учетные записи</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="180"/>
        <source>Network</source>
        <translation>Настройка сети</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="182"/>
        <source>Program settings</source>
        <translation>Настройка приложения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="190"/>
        <source>Help</source>
        <translation>Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="193"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="195"/>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="345"/>
        <location filename="../src/mainwindow.cpp" line="349"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="396"/>
        <location filename="../src/mainwindow.cpp" line="400"/>
        <source>Notification</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="457"/>
        <source>Your message was saved in Drafts.</source>
        <translation>Ваше сообщение сохранено в Черновиках.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="463"/>
        <source>Your message was successfully sent.</source>
        <translation>Ваше сообщение успешно отправлено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="469"/>
        <source>Message was deleted.</source>
        <translation>Сообщение удалено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="499"/>
        <source>/help.html</source>
        <translation>/help_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="500"/>
        <source>Help - %1</source>
        <translation>Справка - %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="517"/>
        <source>/about.html</source>
        <translation>/about_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="518"/>
        <source>About - %1</source>
        <translation>О программе - %1</translation>
    </message>
</context>
<context>
    <name>Profile</name>
    <message>
        <location filename="../src/ui/profile.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="22"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="29"/>
        <source>Surname</source>
        <translation>Фамилия</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="36"/>
        <source>City</source>
        <translation>Город</translation>
    </message>
    <message>
        <location filename="../src/ui/profile.ui" line="43"/>
        <source>Email</source>
        <translation>Электронная почта</translation>
    </message>
</context>
<context>
    <name>UIApplicationSettings</name>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="20"/>
        <source>Settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="28"/>
        <source>Enable window rotation</source>
        <translation>Включить поворот окна</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="35"/>
        <source>Enable multi panel mode</source>
        <translation>Включить многопанельный режим</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="42"/>
        <source>Group news by author</source>
        <translation>Объединять новости по автору</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="51"/>
        <location filename="../src/ui/uiapplicationsettings.cpp" line="44"/>
        <source>Album directory</source>
        <translation>Каталог альбома</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="61"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.ui" line="70"/>
        <source>Clear cache</source>
        <translation>Очистить кэш</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.cpp" line="50"/>
        <source>Wrong directory</source>
        <translation>Неправильный каталог</translation>
    </message>
    <message>
        <location filename="../src/ui/uiapplicationsettings.cpp" line="50"/>
        <source>This directory cannot be used to save photos</source>
        <translation>Выбранный каталог не может быть использован для сохранения изображений</translation>
    </message>
</context>
</TS>

==> mysocials-ui_1.0.5-2.tar.gz: mysocials-ui-1.0.5/translations/mysocials_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/mainwindow.cpp" line="124"/>
        <source>&amp;Friends</source>
        <translation>&amp;Друзья</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="131"/>
        <source>&amp;Messages</source>
        <translation>&amp;Сообщения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="138"/>
        <source>&amp;Albums</source>
        <translation>&amp;Альбомы</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="145"/>
        <source>&amp;News</source>
        <translation>&amp;Новости</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="151"/>
        <source>&amp;More</source>
        <translation>&amp;Другое</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="164"/>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="165"/>
        <source>Full screen</source>
        <translation>Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="170"/>
        <source>&amp;Upload images</source>
        <translation>&amp;Загрузить фотографии</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="175"/>
        <source>&amp;Exit</source>
        <translation>&amp;Выход</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="182"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="185"/>
        <source>Accounts</source>
        <translation>Учетные записи</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="187"/>
        <source>Network</source>
        <translation>Настройка сети</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="189"/>
        <source>Program settings</source>
        <translation>Настройка приложения</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="194"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="197"/>
        <source>MySocials Help</source>
        <translation>Помощь</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="200"/>
        <source>&amp;About</source>
        <translation>&amp;О программе</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="202"/>
        <source>Statistics</source>
        <translation>Статистика</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="352"/>
        <location filename="../src/mainwindow.cpp" line="356"/>
        <source>Error occured</source>
        <translation>Произошла ошибка</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="403"/>
        <location filename="../src/mainwindow.cpp" line="407"/>
        <source>Notification</source>
        <translation>Уведомление</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="464"/>
        <source>Your message was saved in Drafts.</source>
        <translation>Ваше сообщение сохранено в Черновиках.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="470"/>
        <source>Your message was successfully sent.</source>
        <translation>Ваше сообщение успешно отправлено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="476"/>
        <source>Message was deleted.</source>
        <translation>Сообщение удалено.</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="506"/>
        <source>/help.html</source>
        <translation>/help_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="507"/>
        <source>Help - %1</source>
        <translation>Справка - %1</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="524"/>
        <source>/about.html</source>
        <translation>/about_ru.html</translation>
    </message>
    <message>
        <location filename="../src/mainwindow.cpp" line="525"/>
        <source>About - %1</source>
        <translation>О программе - %1</translation>
    </message>
</context>
<context>
    <name>Profile</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Имя</translation>
    </message>
    <message>
        <source>Surname</source>
        <translation type="obsolete">Фамилия</translation>
    </message>
    <message>
        <source>City</source>
        <translation type="obsolete">Город</translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="obsolete">Электронная почта</translation>
    </message>
</context>
<context>
    <name>UIApplicationSettings</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Настройки</translation>
    </message>
    <message>
        <source>Enable window rotation</source>
        <translation type="obsolete">Включить поворот окна</translation>
    </message>
    <message>
        <source>Enable multi panel mode</source>
        <translation type="obsolete">Включить многопанельный режим</translation>
    </message>
    <message>
        <source>Group news by author</source>
        <translation type="obsolete">Объединять новости по автору</translation>
    </message>
    <message>
        <source>Album directory</source>
        <translation type="obsolete">Каталог альбома</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="obsolete">...</translation>
    </message>
    <message>
        <source>Clear cache</source>
        <translation type="obsolete">Очистить кэш</translation>
    </message>
    <message>
        <source>Wrong directory</source>
        <translation type="obsolete">Неправильный каталог</translation>
    </message>
    <message>
        <source>This directory cannot be used to save photos</source>
        <translation type="obsolete">Выбранный каталог не может быть использован для сохранения изображений</translation>
    </message>
</context>
</TS>
